@@ -1,23 +1,20 @@
 /*
- *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
- *	All rights reserved.
+ *      fhist - file history and comparison tools
+ *      Copyright (C) 1993, 1994, 1998, 2002, 2008 Peter Miller
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 3 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to implement missing ANSI C <string.h> functions
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * This file contains functions for use with non-ANSI conforming systems
  * to implement absent ANSI functionality.
@@ -64,8 +61,8 @@ strerror(int n)
 
     if (n < 1 || n > sys_nerr)
     {
-	sprintf(buffer, "Error %d", n);
-	return buffer;
+        sprintf(buffer, "Error %d", n);
+        return buffer;
     }
     return sys_errlist[n];
 }
@@ -83,27 +80,27 @@ strcasecmp(const char *s1, const char *s2)
 
     for (;;)
     {
-	c1 = *s1++;
-	if (islower(c1))
-	    c1 = toupper(c1);
-	c2 = *s2++;
-	if (islower(c2))
-	    c2 = toupper(c2);
-	if (c1 != c2)
-	{
-	    /*
-	     * if s1 is a leading substring of s2, must
-	     * return -1, even if the next character of s2
-	     * is negative.
-	     */
-	    if (!c1)
-		return -1;
-	    if (c1 < c2)
-		return -1;
-	    return 1;
-	}
-	if (!c1)
-	    return 0;
+        c1 = *s1++;
+        if (islower(c1))
+            c1 = toupper(c1);
+        c2 = *s2++;
+        if (islower(c2))
+            c2 = toupper(c2);
+        if (c1 != c2)
+        {
+            /*
+             * if s1 is a leading substring of s2, must
+             * return -1, even if the next character of s2
+             * is negative.
+             */
+            if (!c1)
+                return -1;
+            if (c1 < c2)
+                return -1;
+            return 1;
+        }
+        if (!c1)
+            return 0;
     }
 }
 
@@ -121,102 +118,102 @@ strsignal(int n)
     {
 #ifdef SIGHUP
     case SIGHUP:
-	return "hang up [SIGHUP]";
+        return "hang up [SIGHUP]";
 #endif /* SIGHUP */
 
 #ifdef SIGINT
     case SIGINT:
-	return "user interrupt [SIGINT]";
+        return "user interrupt [SIGINT]";
 #endif /* SIGINT */
 
 #ifdef SIGQUIT
     case SIGQUIT:
-	return "user quit [SIGQUIT]";
+        return "user quit [SIGQUIT]";
 #endif /* SIGQUIT */
 
 #ifdef SIGILL
     case SIGILL:
-	return "illegal instruction [SIGILL]";
+        return "illegal instruction [SIGILL]";
 #endif /* SIGILL */
 
 #ifdef SIGTRAP
     case SIGTRAP:
-	return "trace trap [SIGTRAP]";
+        return "trace trap [SIGTRAP]";
 #endif /* SIGTRAP */
 
 #ifdef SIGIOT
     case SIGIOT:
-	return "abort [SIGIOT]";
+        return "abort [SIGIOT]";
 #endif /* SIGIOT */
 
 #ifdef SIGEMT
     case SIGEMT:
-	return "EMT instruction [SIGEMT]";
+        return "EMT instruction [SIGEMT]";
 #endif /* SIGEMT */
 
 #ifdef SIGFPE
     case SIGFPE:
-	return "floating point exception [SIGFPE]";
+        return "floating point exception [SIGFPE]";
 #endif /* SIGFPE */
 
 #ifdef SIGKILL
     case SIGKILL:
-	return "kill [SIGKILL]";
+        return "kill [SIGKILL]";
 #endif /* SIGKILL */
 
 #ifdef SIGBUS
     case SIGBUS:
-	return "bus error [SIGBUS]";
+        return "bus error [SIGBUS]";
 #endif /* SIGBUS */
 
 #ifdef SIGSEGV
     case SIGSEGV:
-	return "segmentation violation [SIGSEGV]";
+        return "segmentation violation [SIGSEGV]";
 #endif /* SIGSEGV */
 
 #ifdef SIGSYS
     case SIGSYS:
-	return "bad argument to system call [SIGSYS]";
+        return "bad argument to system call [SIGSYS]";
 #endif /* SIGSYS */
 
 #ifdef SIGPIPE
     case SIGPIPE:
-	return "write on a pipe with no one to read it [SIGPIPE]";
+        return "write on a pipe with no one to read it [SIGPIPE]";
 #endif /* SIGPIPE */
 
 #ifdef SIGALRM
     case SIGALRM:
-	return "alarm clock [SIGALRM]";
+        return "alarm clock [SIGALRM]";
 #endif /* SIGALRM */
 
 #ifdef SIGTERM
     case SIGTERM:
-	return "software termination [SIGTERM]";
+        return "software termination [SIGTERM]";
 #endif /* SIGTERM */
 
 #ifdef SIGUSR1
     case SIGUSR1:
-	return "user defined signal one [SIGUSR1]";
+        return "user defined signal one [SIGUSR1]";
 #endif /* SIGUSR1 */
 
 #ifdef SIGUSR2
     case SIGUSR2:
-	return "user defined signal two [SIGUSR2]";
+        return "user defined signal two [SIGUSR2]";
 #endif /* SIGUSR2 */
 
 #ifdef SIGCLD
     case SIGCLD:
-	return "death of child [SIGCLD]";
+        return "death of child [SIGCLD]";
 #endif /* SIGCLD */
 
 #ifdef SIGPWR
     case SIGPWR:
-	return "power failure [SIGPWR]";
+        return "power failure [SIGPWR]";
 #endif /* SIGPWR */
 
     default:
-	sprintf(buffer, "signal %d", n);
-	return buffer;
+        sprintf(buffer, "signal %d", n);
+        return buffer;
     }
 }
 
