@@ -1,26 +1,23 @@
 /*
- *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998, 2000-2002 Peter Miller;
- *	All rights reserved.
+ *      fhist - file history and comparison tools
+ *      Copyright (C) 1991-1994, 1998, 2000-2002, 2008 Peter Miller
  *
- *	Derived from a work
- *	Copyright (C) 1990 David I. Bell.
+ *      Derived from a work
+ *      Copyright (C) 1990 David I. Bell.
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 3 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to isolate malloc
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * Malloc interludes which allow for releasing of all used memory blocks.
  * Just call cm_reset whenever you want to free all allocated memory.
@@ -45,7 +42,7 @@
 #undef calloc
 
 
-#define	MAGIC	54928347L
+#define MAGIC   54928347L
 
 /*
  * This is to protect DOS.
@@ -58,22 +55,22 @@
 #define BIG ((unsigned int)-1)
 
 
-typedef	struct chunk	CHUNK;
+typedef struct chunk    CHUNK;
 struct chunk
 {
-    CHUNK	*next;		/* next chunk in chain */
-    CHUNK	*prev;		/* previous chunk in chain */
-    long	magic;		/* magic value */
-    double	data[1];	/* data storage (varying size) */
+    CHUNK       *next;          /* next chunk in chain */
+    CHUNK       *prev;          /* previous chunk in chain */
+    long        magic;          /* magic value */
+    double      data[1];        /* data storage (varying size) */
 };
 
-#define	CHUNKSIZE(size) (sizeof(CHUNK) + (size) - sizeof(double))
+#define CHUNKSIZE(size) (sizeof(CHUNK) + (size) - sizeof(double))
 
-#define	DPTOCP(dp) \
-	((CHUNK *)(void*)(((char *)(dp)) - offsetof(CHUNK, data[0])))
+#define DPTOCP(dp) \
+        ((CHUNK *)(void*)(((char *)(dp)) - offsetof(CHUNK, data[0])))
 
 
-static	CHUNK	head = {&head, &head};
+static  CHUNK   head = {&head, &head};
 
 
 /*
@@ -88,13 +85,13 @@ r_alloc(size_t size)
 
     if (size > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     errno = 0;
     result = malloc((unsigned int) size);
     if (!result && !errno)
-	errno = ENOMEM;
+        errno = ENOMEM;
     return result;
 }
 
@@ -106,13 +103,13 @@ r_realloc(void *dp, size_t size)
 
     if (size > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     errno = 0;
     result = realloc(dp, (unsigned int) size);
     if (!result && !errno)
-	errno = ENOMEM;
+        errno = ENOMEM;
     return result;
 }
 
@@ -124,7 +121,7 @@ r_realloc_and_check(void *a, size_t b)
 
     result = r_realloc(a, b);
     if (!result)
-	nfatal_raw("realloc(%lu)", (unsigned long)b);
+        nfatal_raw("realloc(%lu)", (unsigned long)b);
     return result;
 }
 
@@ -143,7 +140,7 @@ r_alloc_and_check(size_t n)
 
     result = r_alloc(n);
     if (!result)
-       	nfatal_raw("malloc(%lu)", (unsigned long)n);
+        nfatal_raw("malloc(%lu)", (unsigned long)n);
     return result;
 }
 
@@ -159,12 +156,12 @@ cm_alloc(size_t size)
 
     if (size > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     cp = (CHUNK *)r_alloc((size_t)CHUNKSIZE(size));
     if (!cp)
-	return 0;
+        return 0;
     cp->magic = MAGIC;
     cp->next = head.next;
     cp->next->prev = cp;
@@ -181,7 +178,7 @@ cm_alloc_and_check(size_t n)
 
     result = cm_alloc(n);
     if (!result)
-	nfatal_raw("malloc(%lu)", (unsigned long)n);
+        nfatal_raw("malloc(%lu)", (unsigned long)n);
     return result;
 }
 
@@ -197,25 +194,25 @@ cm_realloc(void *dp, size_t size)
 
     if (!dp || size > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     cp = DPTOCP(dp);
     if (cp->magic != MAGIC)
     {
-	error_raw
-	(
-    	    "%s: %d: bad realloc %08lX (bug)",
-    	    __FILE__,
-    	    __LINE__,
-    	    (unsigned long)dp
-	);
-	errno = EINVAL;
-	return 0;
+        error_raw
+        (
+            "%s: %d: bad realloc %08lX (bug)",
+            __FILE__,
+            __LINE__,
+            (unsigned long)dp
+        );
+        errno = EINVAL;
+        return 0;
     }
     cp = (CHUNK *)r_realloc(cp, (size_t)CHUNKSIZE(size));
     if (!cp)
-	return 0;
+        return 0;
     cp->next->prev = cp;
     cp->prev->next = cp;
     return (void *)cp->data;
@@ -229,7 +226,7 @@ cm_realloc_and_check(void *a, size_t b)
 
     result = cm_realloc(a, b);
     if (!result)
-	nfatal_raw("malloc(%lu)", (unsigned long)b);
+        nfatal_raw("malloc(%lu)", (unsigned long)b);
     return result;
 }
 
@@ -246,18 +243,18 @@ cm_calloc(size_t nelem, size_t elsize)
 
     if (nelem > BIG || elsize > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     totalsize = CHUNKSIZE(nelem * elsize);
     if (totalsize > BIG)
     {
-	errno = EINVAL;
-	return 0;
+        errno = EINVAL;
+        return 0;
     }
     cp = (CHUNK *)r_alloc(totalsize);
     if (!cp)
-	return 0;
+        return 0;
     cp->magic = MAGIC;
     cp->next = head.next;
     cp->next->prev = cp;
@@ -274,7 +271,7 @@ cm_calloc_and_check(size_t a, size_t b)
 
     result = cm_calloc(a, b);
     if (!result)
-	nfatal_raw("malloc(%lu)", (unsigned long)b);
+        nfatal_raw("malloc(%lu)", (unsigned long)b);
     return result;
 }
 
@@ -289,18 +286,18 @@ cm_free(void *dp)
     CHUNK           *cp;
 
     if (!dp)
-	return;
+        return;
     cp = DPTOCP(dp);
     if (cp->magic != MAGIC)
     {
-	error_raw
-	(
-    	    "%s: %d: bad free %08lX (bug)",
-    	    __FILE__,
-    	    __LINE__,
-    	    (unsigned long)dp
-	);
-	return;
+        error_raw
+        (
+            "%s: %d: bad free %08lX (bug)",
+            __FILE__,
+            __LINE__,
+            (unsigned long)dp
+        );
+        return;
     }
     cp->prev->next = cp->next;
     cp->next->prev = cp->prev;
@@ -323,23 +320,23 @@ cm_reset(void)
 
     while (head.next != &head)
     {
-	cp = head.next;
-	if (cp->magic != MAGIC)
-	{
-	    error_raw
-	    (
-		"%s: %d: bad cm_reset %08lX (bug)",
-		__FILE__,
-		__LINE__,
-		(unsigned long)cp
-	    );
-	    break;
-	}
-	head.next = cp->next;
-	cp->next = 0;
-	cp->prev = 0;
-	cp->magic = 0;
-	r_free(cp);
+        cp = head.next;
+        if (cp->magic != MAGIC)
+        {
+            error_raw
+            (
+                "%s: %d: bad cm_reset %08lX (bug)",
+                __FILE__,
+                __LINE__,
+                (unsigned long)cp
+            );
+            break;
+        }
+        head.next = cp->next;
+        cp->next = 0;
+        cp->prev = 0;
+        cp->magic = 0;
+        r_free(cp);
     }
     head.next = &head;
     head.prev = &head;
