@@ -1,23 +1,20 @@
 /*
- *	fhist - file history and comparison tools
- *	Copyright (C) 2000-2002 Peter Miller;
- *	All rights reserved.
+ *      fhist - file history and comparison tools
+ *      Copyright (C) 2000-2002, 2008 Peter Miller
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 3 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions for reading input
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <ac/ctype.h>
@@ -53,7 +50,7 @@ input_name(input_ty *fp)
 long
 input_length(input_ty *fp)
 {
-    long	    result;
+    long            result;
 
     trace(("input_length(fp = %8.8lX)\n{\n", (long)fp));
     result = fp->vptr->length(fp);
@@ -70,7 +67,7 @@ input_length(input_ty *fp)
 long
 input_ftell(input_ty *fp)
 {
-    long	    result;
+    long            result;
 
     trace(("input_ftell(fp = %8.8lX)\n{\n", (long)fp));
     result = fp->vptr->ftell(fp) - fp->pushback_len;
@@ -87,26 +84,26 @@ input_ftell(input_ty *fp)
 long
 input_read(input_ty *fp, void *data, long len)
 {
-    long	    result;
+    long            result;
 
     trace(("input_read(fp = %8.8lX, data = %8.8lX, len = %8.8lX)\n{\n",
-	(long)fp, (long)data, len));
+        (long)fp, (long)data, len));
     if (len <= 0)
     {
-	result = 0;
+        result = 0;
     }
     else
     {
-	if (fp->pushback_len > 0)
-	{
-	    fp->pushback_len--;
-	    *(char *)data = fp->pushback_buf[fp->pushback_len];
-	    result = 1;
-	}
-	else
-	{
-	    result = fp->vptr->read(fp, data, len);
-	}
+        if (fp->pushback_len > 0)
+        {
+            fp->pushback_len--;
+            *(char *)data = fp->pushback_buf[fp->pushback_len];
+            result = 1;
+        }
+        else
+        {
+            result = fp->vptr->read(fp, data, len);
+        }
     }
     trace(("return %ld;\n", result));
     trace(("}\n"));
@@ -119,24 +116,24 @@ input_read(input_ty *fp, void *data, long len)
 static char *
 unctrl(int c)
 {
-    static char	    buffer[10];
+    static char     buffer[10];
 
     if (c < 0 || c >= 256)
     {
-	snprintf(buffer, sizeof(buffer), "%d", c);
-	return buffer;
+        snprintf(buffer, sizeof(buffer), "%d", c);
+        return buffer;
     }
     switch (c)
     {
     case '\'':
     case '\\':
-	escape:
-	buffer[0] = '\'';
-	buffer[1] = '\\';
-	buffer[2] = c;
-	buffer[3] = '\'';
-	buffer[4] = 0;
-	break;
+        escape:
+        buffer[0] = '\'';
+        buffer[1] = '\\';
+        buffer[2] = c;
+        buffer[3] = '\'';
+        buffer[4] = 0;
+        break;
 
     case '\b': c = 'b'; goto escape;
     case '\f': c = 'f'; goto escape;
@@ -145,16 +142,16 @@ unctrl(int c)
     case '\t': c = 't'; goto escape;
 
     default:
-	if (isprint((unsigned char)c))
-	{
-	    buffer[0] = '\'';
-	    buffer[1] = c;
-	    buffer[2] = '\'';
-	    buffer[3] = 0;
-	}
-	else
-	    snprintf(buffer, sizeof(buffer), "'\\%o'", c);
-	break;
+        if (isprint((unsigned char)c))
+        {
+            buffer[0] = '\'';
+            buffer[1] = c;
+            buffer[2] = '\'';
+            buffer[3] = 0;
+        }
+        else
+            snprintf(buffer, sizeof(buffer), "'\\%o'", c);
+        break;
     }
     return buffer;
 }
@@ -170,16 +167,16 @@ unctrl(int c)
 int
 input_getc(input_ty *fp)
 {
-    int		    result;
+    int             result;
 
     trace(("input_getc(fp = %8.8lX)\n{\n", (long)fp));
     if (fp->pushback_len > 0)
     {
-	fp->pushback_len--;
-	result = fp->pushback_buf[fp->pushback_len];
+        fp->pushback_len--;
+        result = fp->pushback_buf[fp->pushback_len];
     }
     else
-	result = fp->vptr->get(fp);
+        result = fp->vptr->get(fp);
     trace(("return %s;\n", unctrl(result)));
     trace(("}\n"));
     return result;
@@ -196,13 +193,13 @@ input_ungetc(input_ty *fp, int c)
     trace(("input_ungetc(fp = %8.8lX, c = %s)\n{\n", (long)fp, unctrl(c)));
     if (c >= 0)
     {
-	if (fp->pushback_len >= fp->pushback_max)
-	{
-	    fp->pushback_max = 16 + 2 * fp->pushback_max;
-	    fp->pushback_buf =
-		    mem_change_size(fp->pushback_buf, fp->pushback_max);
-	}
-	fp->pushback_buf[fp->pushback_len++] = c;
+        if (fp->pushback_len >= fp->pushback_max)
+        {
+            fp->pushback_max = 16 + 2 * fp->pushback_max;
+            fp->pushback_buf =
+                    mem_change_size(fp->pushback_buf, fp->pushback_max);
+        }
+        fp->pushback_buf[fp->pushback_len++] = c;
     }
     trace(("}\n"));
 }
@@ -213,9 +210,9 @@ input_delete(input_ty *fp)
 {
     trace(("input_delete(fp = %8.8lX)\n{\n", (long)fp));
     if (fp->vptr->destruct)
-	fp->vptr->destruct(fp);
+        fp->vptr->destruct(fp);
     if (fp->pushback_buf)
-	mem_free(fp->pushback_buf);
+        mem_free(fp->pushback_buf);
     fp->pushback_buf = 0;
     fp->pushback_len = 0;
     fp->pushback_max = 0;
@@ -241,58 +238,58 @@ input_delete(input_ty *fp)
 char *
 input_readline(input_ty *fp, long *retlen, int keep, int *is_bin_file)
 {
-    char	    *dp;	/* destination pointer */
-    size_t	    totallen;	/* total length of data */
-    static char	*linebuffer;	/* common line buffer */
+    char            *dp;        /* destination pointer */
+    size_t          totallen;   /* total length of data */
+    static char *linebuffer;    /* common line buffer */
     static size_t    linelength; /* total length of line */
 
     trace(("input_readline(fp = %8.8lX, retlen = %8.8lX, keep = %d)\n{\n",
-	(long)fp, (long)retlen, keep));
+        (long)fp, (long)retlen, keep));
     if (linelength == 0)
     {
-	/* allocate line buffer */
-	linelength = 16;
-	linebuffer = r_alloc_and_check(linelength + 1);
+        /* allocate line buffer */
+        linelength = 16;
+        linebuffer = r_alloc_and_check(linelength + 1);
     }
     totallen = 0;
     for (;;)
     {
-	int c = input_getc(fp);
-	if (c < 0)
-	{
-	    if (totallen == 0)
-	       	return 0;
-	    warning_last_line_unterminated(input_name(fp));
-	    c = '\n';
-	}
-	if (c == 0)
-	{
-	    *is_bin_file = 1;
-	    c = 0x80;
-	}
-	if (totallen >= linelength)
-	{
-	    /*
-	     * doubling gives O(1) behaviour
-	     * over the life of the prog
-	     */
-	    linelength = linelength * 2 + 16;
-	    linebuffer = r_realloc_and_check(linebuffer, linelength + 1);
-	}
-	linebuffer[totallen++] = c;
-	if (c == '\n')
-	    break;
+        int c = input_getc(fp);
+        if (c < 0)
+        {
+            if (totallen == 0)
+                return 0;
+            warning_last_line_unterminated(input_name(fp));
+            c = '\n';
+        }
+        if (c == 0)
+        {
+            *is_bin_file = 1;
+            c = 0x80;
+        }
+        if (totallen >= linelength)
+        {
+            /*
+             * doubling gives O(1) behaviour
+             * over the life of the prog
+             */
+            linelength = linelength * 2 + 16;
+            linebuffer = r_realloc_and_check(linebuffer, linelength + 1);
+        }
+        linebuffer[totallen++] = c;
+        if (c == '\n')
+            break;
     }
     linebuffer[totallen] = 0;
 
     if (retlen)
-	    *retlen = totallen;
+            *retlen = totallen;
     if (!keep)
-	dp = linebuffer;
+        dp = linebuffer;
     else
     {
-	dp = cm_alloc_and_check(totallen + 1);
-	memcpy(dp, linebuffer, (size_t)totallen);
+        dp = cm_alloc_and_check(totallen + 1);
+        memcpy(dp, linebuffer, (size_t)totallen);
     }
     trace(("return %8.8lX;\n", (long)dp));
     trace(("}\n"));
@@ -305,10 +302,10 @@ input_skip_lines(input_ty *fp, int numlines)
 {
     while (numlines > 0)
     {
-	int c = input_getc(fp);
-	if (c < 0)
-    	    break;
-	if (c == '\n')
-    	    --numlines;
+        int c = input_getc(fp);
+        if (c < 0)
+            break;
+        if (c == '\n')
+            --numlines;
     }
 }
