@@ -1,23 +1,20 @@
 /*
- *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2002 Peter Miller;
- *	All rights reserved.
+ *      fhist - file history and comparison tools
+ *      Copyright (C) 1998, 2002, 2008 Peter Miller
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 3 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate exprs
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <sub/expr.h>
@@ -42,10 +39,10 @@ sub_expression(sub_context_ty *scp, wstring_list_ty *arg)
     trace(("sub_expression()\n{\n"));
     if (arg->nitems < 2)
     {
-	sub_context_error_set(scp, i18n("requires at least one argument"));
-	trace(("return NULL;\n"));
-	trace(("}\n"));
-	return 0;
+        sub_context_error_set(scp, i18n("requires at least one argument"));
+        trace(("return NULL;\n"));
+        trace(("}\n"));
+        return 0;
     }
 
     /*
@@ -60,9 +57,9 @@ sub_expression(sub_context_ty *scp, wstring_list_ty *arg)
     str_free(s1);
     if (!s2)
     {
-	trace(("return NULL;\n"));
-	trace(("}\n"));
-	return 0;
+        trace(("return NULL;\n"));
+        trace(("}\n"));
+        return 0;
     }
 
     /*
