@@ -1,23 +1,20 @@
 /*
- *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2002 Peter Miller;
- *	All rights reserved.
+ *      fhist - file history and comparison tools
+ *      Copyright (C) 1998, 2002, 2008 Peter Miller
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 3 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for common/wstr_list.c
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #ifndef COMMON_WSTR_LIST_H
@@ -28,9 +25,9 @@
 typedef struct wstring_list_ty wstring_list_ty;
 struct wstring_list_ty
 {
-	size_t		nitems;
-	size_t		nitems_max;
-	wstring_ty	**item;
+        size_t          nitems;
+        size_t          nitems_max;
+        wstring_ty      **item;
 };
 
 int wstring_list_member(wstring_list_ty *, wstring_ty *);
