@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # fhist - file history and comparison tools
-# Copyright (C) 1998, 2008 Peter Miller
+# Copyright (C) 1998, 2008, 2009 Peter Miller
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,16 +18,16 @@
 #
 sortflag=
 if test "$1" = "-r"; then
-        sortflag=r
-        shift
+    sortflag=-r
+    shift
 fi
 echo $* |
 tr ' ' '\12' |
-sort -t. +1n$sortflag -2 +2n$sortflag -3 +3n$sortflag -5 |
+sort $sortflag -n -t. -k 2,2.2 -k 3 |
 while read f
 do
-        echo ".br"
-        echo ".ne 3i"
-        echo ".so $f"
+    echo ".br"
+    echo ".ne 2i"
+    echo ".so $f"
 done
 exit 0
